@@ -1,6 +1,6 @@
 
 from PySide6 import QtCore, QtUiTools
-from mplwidget import MplWidget
+from .mplwidget import MplWidget
 
 def loadUiWidget(uifilename, parent=None):
     loader = QtUiTools.QUiLoader()
