@@ -1,6 +1,6 @@
 from PySide6 import QtWidgets
 from PySide6.QtWidgets import QTableWidgetItem
-from loadgui import loadUiWidget
+from .loadgui import loadUiWidget
 import numpy as np
 
 
