@@ -7,9 +7,9 @@ from PySide6.QtWidgets import  QApplication, QFileDialog, QMainWindow
 
 from scipy import optimize as optim
 import re
-from export import export_fit
-from loadgui import loadUiWidget
-from options import Options_
+from .export import export_fit
+from .loadgui import loadUiWidget
+from .options import Options_
 from pathlib import Path
 
 class function():
